//
//  OgreTutorial3AppDelegate.m
//  OgreTutorial3
//
//  Created by Will Thimbleby on 1/29/11.
//  Copyright 2011 Will Thimbleby. All rights reserved.
//

#import "OgreTutorial3AppDelegate.h"

using namespace Ogre;

@implementation OgreTutorial3AppDelegate

- (void)applicationDidFinishLaunching:(NSNotification *)notification
{
	std::string mResourcePath = [[[NSBundle mainBundle] resourcePath]
        cStringUsingEncoding:NSUTF8StringEncoding];
	
	// Create a new root object with the correct paths
	Root *mRoot = new Root(mResourcePath + "/plugins.cfg", mResourcePath + "/ogre.cfg",
		mResourcePath + "/ogre.log");
	mRoot->setRenderSystem(mRoot->getAvailableRenderers().front());
	
	// Show a configure box and exit if user clicked cancel
	if(!mRoot->showConfigDialog())
		return;
	
	// Initialise
	RenderWindow *mWindow = mRoot->initialise(true);
	SceneManager *mSceneMgr = mRoot->createSceneManager(ST_GENERIC, "My scene manager");
    
	// Add resource locations
	ResourceGroupManager::getSingleton().addResourceLocation(mResourcePath,
        std::string("FileSystem"), ResourceGroupManager::DEFAULT_RESOURCE_GROUP_NAME);
	ResourceGroupManager::getSingleton().initialiseAllResourceGroups();
	
	// Create the camera, node & attach camera
	Camera *mCamera = mSceneMgr->createCamera("My camera");
	SceneNode *camNode = mSceneMgr->getRootSceneNode()->createChildSceneNode();
	camNode->attachObject(mCamera);
	mWindow->addViewport(mCamera);
    
    // Create a light
    mSceneMgr->setAmbientLight(ColourValue(0, 0, 0));
    mSceneMgr->createLight("MainLight");
    
    // Add a object, give it it's own node
    mObjectNode = mSceneMgr->getRootSceneNode()->createChildSceneNode();
    Entity *knot = mSceneMgr->createEntity("knot", "knot.mesh");
    mObjectNode->attachObject(knot);
    mObjectNode->setPosition(Vector3(0, 0, -500));
    
    // create a timer that causes OGRE to render at 50fps
    [NSTimer scheduledTimerWithTimeInterval:0.02 target:self selector:@selector(renderFrame)
        userInfo:NULL repeats:YES];
}

- (void)renderFrame
{
    Ogre::Root::getSingleton().renderOneFrame();
    mObjectNode->rotate(Vector3(0, 1, 0), Radian(0.01));
}

@end
